@@ -58,4 +58,4 @@ def array_to_string(array, indent: str = "    "):
 
 
 def print_array(array, indent: str = "    "):
-    print(array_to_string(array, indent))
\ No newline at end of file
+    print(array_to_string(array, indent), end="")
\ No newline at end of file
